#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   taffybar
version:                4.1.0
visibility:             public
id:                     taffybar-4.1.0-7TxYVemd0JN74WfSJRPGLn
key:                    taffybar-4.1.0-7TxYVemd0JN74WfSJRPGLn
license:                BSD-3-Clause
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               http://github.com/taffybar/taffybar
synopsis:               A desktop bar similar to xmobar, but with more GUI
category:               System
abi:                    da83ec5a77f66ac6a6b3d73db8771886
exposed:                True
exposed-modules:
    System.Taffybar System.Taffybar.Auth System.Taffybar.Context
    System.Taffybar.DBus System.Taffybar.DBus.Toggle
    System.Taffybar.Example System.Taffybar.Hooks
    System.Taffybar.Information.Battery System.Taffybar.Information.CPU
    System.Taffybar.Information.CPU2 System.Taffybar.Information.Chrome
    System.Taffybar.Information.Crypto
    System.Taffybar.Information.DiskIO
    System.Taffybar.Information.EWMHDesktopInfo
    System.Taffybar.Information.MPRIS2
    System.Taffybar.Information.Memory
    System.Taffybar.Information.Network
    System.Taffybar.Information.SafeX11
    System.Taffybar.Information.StreamInfo
    System.Taffybar.Information.X11DesktopInfo
    System.Taffybar.Information.XDG.Protocol
    System.Taffybar.LogFormatter System.Taffybar.SimpleConfig
    System.Taffybar.Support.PagerHints System.Taffybar.Util
    System.Taffybar.Widget System.Taffybar.Widget.Battery
    System.Taffybar.Widget.CPUMonitor
    System.Taffybar.Widget.CommandRunner System.Taffybar.Widget.Crypto
    System.Taffybar.Widget.DiskIOMonitor
    System.Taffybar.Widget.FSMonitor
    System.Taffybar.Widget.FreedesktopNotifications
    System.Taffybar.Widget.Generic.AutoSizeImage
    System.Taffybar.Widget.Generic.ChannelGraph
    System.Taffybar.Widget.Generic.ChannelWidget
    System.Taffybar.Widget.Generic.DynamicMenu
    System.Taffybar.Widget.Generic.Graph
    System.Taffybar.Widget.Generic.Icon
    System.Taffybar.Widget.Generic.PollingBar
    System.Taffybar.Widget.Generic.PollingGraph
    System.Taffybar.Widget.Generic.PollingLabel
    System.Taffybar.Widget.Generic.VerticalBar
    System.Taffybar.Widget.Layout System.Taffybar.Widget.MPRIS2
    System.Taffybar.Widget.NetworkGraph System.Taffybar.Widget.SNITray
    System.Taffybar.Widget.SimpleClock
    System.Taffybar.Widget.SimpleCommandButton
    System.Taffybar.Widget.Text.CPUMonitor
    System.Taffybar.Widget.Text.MemoryMonitor
    System.Taffybar.Widget.Text.NetworkMonitor
    System.Taffybar.Widget.Util System.Taffybar.Widget.Weather
    System.Taffybar.Widget.Windows System.Taffybar.Widget.Workspaces
    System.Taffybar.Widget.WttrIn System.Taffybar.Widget.XDGMenu.Menu
    System.Taffybar.Widget.XDGMenu.MenuWidget
    System.Taffybar.WindowIcon

hidden-modules:
    Paths_taffybar System.Taffybar.DBus.Client.MPRIS2
    System.Taffybar.DBus.Client.Params
    System.Taffybar.DBus.Client.UPower
    System.Taffybar.DBus.Client.UPowerDevice
    System.Taffybar.DBus.Client.Util

import-dirs:            /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/taffybar
hs-libraries:           HStaffybar-4.1.0-7TxYVemd0JN74WfSJRPGLn
extra-libraries:
    gtk-3 gdk-3 pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0 z

extra-libraries-static:
    gtk-3 gdk-3 pangocairo-1.0 m Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m
    glycin-2 seccomp lcms2 pthread atk-bridge-2.0 atspi Xtst Xi Xfixes
    atk-1.0 dbus-1 xkbcommon wayland-cursor wayland-egl wayland-client
    m rt epoxy dl GL EGL pangoft2-1.0 m pango-1.0 m fribidi thai datrie
    Xft cairo m dl fontconfig m expat m Xext Xrender X11 pthread
    xcb-render xcb-shm xcb Xau Xdmcp pixman-1 m harfbuzz-gobject
    harfbuzz m freetype dl bz2 png16 m m brotlidec brotlicommon
    graphite2 gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0 atomic m
    pcre2-8 pthread z mount blkid systemd sysprof-capture-4

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0 /usr/include
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/glycin-2
    /usr/include/at-spi2-atk/2.0 /usr/include/at-spi-2.0
    /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    HStringTemplate-0.8.8-9PnY4nAQUs91ebLqmmuIS1
    X11-1.10.3-4bnVd3SdcvsJN8LDt8CJay
    aeson-2.2.2.0-JRwGfw4G4faAdkvjZDffZf
    ansi-terminal-1.1-3WEwGthe7is1LBGeoKnQZb base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-5N1D7XReUYC7Q0FFK7LvDS
    containers-0.6.7 data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    dbus-1.3.3-Jf7mwj5GDMdJxfIjTmAprS
    dbus-hslogger-0.1.1.0-7hs4oatUEufKrlMK3FNyDg directory-1.3.8.5
    dyre-0.9.2-7Le4jOC75atJ5aaluPymeQ
    either-5.0.3-An5ds5OCaUP6UEStud2wBg
    enclosed-exceptions-1.0.3-3UKXF9q0zDj4MquHQV0Ojd filepath-1.4.300.1
    fsnotify-0.4.4.0-90y5uFTQYPJ4ST3vqizKOk
    gi-cairo-connector-0.1.1-D0U1re368qZQqjmx5WMdx
    gi-cairo-render-0.1.2-JdP4qcV58CK5zF8T3UE7fa
    gi-gdk-3.0.29-3zgQU9hIOvxAeEGYvRS67V
    gi-gdkpixbuf-2.0.32-KEbkBsjQ7QG5HvkMLnqfER
    gi-gdkx11-3.0.16-71uSwYKjD7q8nUupF5muh1
    gi-glib-2.0.30-BHtwWlNcRihIg7p85mt61G
    gi-gtk-3.0.43-3oJwlETUkMT9dL87C2zISz
    gi-gtk-hs-0.3.17-8afRYnOtvvd1sEZdRXIfZy
    gi-pango-1.0.30-BmTINc4HZsCLXfKRDpvVbS
    gtk-sni-tray-0.1.8.1-DPi1bPGUqH7CQs1Hd2eWdE
    gtk-strut-0.1.3.2-7TRvVST4rMVFBRNNyt7Ymq
    haskell-gi-base-0.26.9-A51M6LjdiVN4RjdHJdLeji
    hslogger-1.3.2.0-24aKRc5FxtEKsaLPvfETXJ
    http-client-0.7.19-34xXemB7zi7LDrAIS2UIas
    http-client-tls-0.3.6.4-ADnxKMmkuxZIenWWL3GTLT
    http-conduit-2.3.9.1-1YnFk244Wc91jkGBAdKo7A
    http-types-0.12.4-EqZKGcmXGQgIrxcsE0a1PI
    multimap-1.2.1-4W8aWHvVl9g78Tpaptjwyw parsec-3.1.16.1
    process-1.6.19.0 rate-limit-1.4.3-6ydvOkN3EwQLZ5xS3sVlHp
    regex-compat-0.95.2.2-DwcD5qxZGc67j8Pwq49pag
    safe-0.3.21-9y1UyAWqaZD9sixo0tZ214
    scotty-0.22-6jkyTCgxz2UDmR58f36Dyx
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl
    status-notifier-item-0.3.2.1-EgOj0MpsWo3GvqgCoyPnUe stm-2.5.1.0
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-8XUEctZKps57K6Zw5siYoh
    time-units-1.0.0-5DRkw9RXZDICp7PYN09sTv transformers-0.6.1.0
    tuple-0.3.0.2-Cakbvc3zdCBL3LJbLfYfKF unix-2.8.4.0
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    xdg-basedir-0.2.2-DLaKUfv1JJAFBfkP0BUklH
    xdg-desktop-entry-0.1.1.4-Lr8ZEwkzza45nK0eEkhjDH
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-helpers-1.0.0-4qhWXJoUbtX94cToL5WE9g
    xmonad-0.18.1-8Lwfl5C7etU5ygtISYZijk

haddock-interfaces:     /usr/share/doc/taffybar/html/taffybar.haddock
haddock-html:           /usr/share/doc/taffybar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-taffybar-z-testlib
version:              4.1.0
package-name:         taffybar
lib-name:             testlib
id:                   taffybar-4.1.0-GdmLiUxFlSnLBMr9kJVymc-testlib
key:                  taffybar-4.1.0-GdmLiUxFlSnLBMr9kJVymc-testlib
license:              BSD-3-Clause
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             http://github.com/taffybar/taffybar
synopsis:             A desktop bar similar to xmobar, but with more GUI
category:             System
abi:                  7f4248d988bdf3f039b120788c14f3d5
exposed-modules:
    System.Taffybar.Test.DBusSpec System.Taffybar.Test.UtilSpec
    System.Taffybar.Test.XvfbSpec TestLibSpec

import-dirs:          /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/taffybar
hs-libraries:         HStaffybar-4.1.0-GdmLiUxFlSnLBMr9kJVymc-testlib
depends:
    QuickCheck-2.15.0.1-GIIsjuuZeTD5REN3cOn4Nc
    attoparsec-0.14.4-Lt8CzeQB1UCKNIPCgGeJTD base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    dbus-1.3.3-Jf7mwj5GDMdJxfIjTmAprS
    extra-1.7.16-8D2X0x8oD0MLkMWmsVnRML filepath-1.4.300.1
    hslogger-1.3.2.0-24aKRc5FxtEKsaLPvfETXJ
    hspec-2.11.7-7gnoQNyRayg3C2dCwMP172
    taffybar-4.1.0-7TxYVemd0JN74WfSJRPGLn text-2.0.2
    typed-process-0.2.13.0-J9Ok4xKz1UuGZMKGl1m6ET unix-2.8.4.0
    unliftio-0.2.25.1-wbCzY6GGN1Jjb0ZnqHZMi
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:   /usr/share/doc/taffybar/html/taffybar.haddock
haddock-html:         /usr/share/doc/taffybar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

